==> manydhcp2.5.2.tar.bz2: manydhcp/index.php <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<?php
  ///////////////////////////////////////////////////
  //Вход в систему
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

 //определяем локаль пришедшего и подставляем нужный язык.
  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("lang/".$lang."/".$lang.".php")) include "lang/".$lang."/".$lang.".php";
     else include "lang/ru/ru.php";

  if(!isset($button)) $button = $TEXT['btn_enter'];
  if(!isset($action)) $action = "login.php";
?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="ROBOTS" content="NOINDEX, NOFOLLOW" />
<title><?php echo $TEXT['global-title']; ?></title>
<link rel="StyleSheet" type="text/css" href="skins/black/reader.css" />
<link rel="icon" href="favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />
</head>
<body>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<div class="horizon">
<table width="100%" height="100%" border="0" class="textPage">
<tr><td width="30%" ></td><td class="logontit" width="70%" ><?php echo $TEXT['global-title']; ?><br /><br />&nbsp;
  <table border="0" width="60%" align="right" topmargin="0" >
<tr><td width="17%" ></td><td></td></tr>
<tr><td class="logondat"><?php echo $TEXT['login-login']; ?></td><td class="logondat2"><input class="loginform" size=10 maxlength=100 type=text name=login ></td></tr>
<tr><td class="logondat"><?php echo $TEXT['login-password']; ?></td><td class="logondat2"><input class="loginform" size=10 maxlength=100 type=password name=password ></td></tr>
<tr><td colspan="2" class="logondat"><input type=submit value='<?php echo $button; ?>'></td></tr>
   </table>
</td><td width="7%"></td></tr>
<tr height="25%" ><td ></td><td class="logonbot"><?php echo $TEXT['global-vertion']; ?>&nbsp;&nbsp;</td><td></td></tr>
<tr height="10%" ><td ></td><td></td><td></td></tr>
</table>
</div>
</form>
</body>
</html>

==> manydhcp2.7.2.tar.bz2: manydhcp/index.php <==
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<?php
  ///////////////////////////////////////////////////
  //Вход в систему
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

 //определяем локаль пришедшего и подставляем нужный язык.
  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("lang/".$lang."/".$lang.".php")) {include "lang/".$lang."/".$lang.".php";}
     else {include "lang/ru/ru.php";}

  $button = $TEXT['btn_enter'];
  $action = "login.php";
?>
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<meta name="ROBOTS" content="NOINDEX, NOFOLLOW" />
<title><?php echo $TEXT['global-title']; ?></title>
<link rel="StyleSheet" type="text/css" href="skins/black/reader.css" />
<link rel="icon" href="favicon.ico" type="image/x-icon" />
<link rel="shortcut icon" href="favicon.ico" type="image/x-icon" />
</head>
<body>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<div class="horizon">
<table width="100%" height="100%" border="0" class="textPage">
<tr><td width="30%" ></td><td class="logontit" width="70%" ><?php echo $TEXT['global-title']; ?><br /><br />&nbsp;
  <table border="0" width="60%" align="right" topmargin="0" >
<tr><td width="17%" ></td><td></td></tr>
<tr><td class="logondat"><?php echo $TEXT['login-login']; ?></td><td class="logondat2"><input class="loginform" size=10 maxlength=100 type=text name=login ></td></tr>
<tr><td class="logondat"><?php echo $TEXT['login-password']; ?></td><td class="logondat2"><input class="loginform" size=10 maxlength=100 type=password name=password ></td></tr>
<tr><td colspan="2" class="logondat"><input type=submit value='<?php echo $button; ?>'></td></tr>
   </table>
</td><td width="7%"></td></tr>
<tr height="25%" ><td ></td><td class="logonbot"><?php echo $TEXT['global-vertion']; ?>&nbsp;&nbsp;</td><td></td></tr>
<tr height="10%" ><td ></td><td></td><td></td></tr>
</table>
</div>
</form>
</body>
</html>
